function [probs,avgprec,reveal] = VNviaCAN(n,m,Lam,A,observe,truth)

% syntax is [probs,avgprec,reveal] = VNviaCAN(n,m,Lam,A,observe,truth)
%  n is vector of nonseed block sizes
%  m is vector of seed block sizes
%  Lam is communications matrix 
%  A is adjacency matrix
%  probs are EXACT conditional probabilties of being class1 given A etc
%  reveal is indicators of correctness along nomination list

% pre-pre-alpha version of Sept 3. 2013

K=length(n);
sumn=sum(n);
summ=sum(m);

% making all partitions

PART=nchoosek([1:sumn],n(1));
for j=2:K
    [a,b]=size(PART);
    PARTCOMP=zeros(a,sumn-b);
    for c=1:a
        temp=[1:sumn];
        for d=1:b
            temp(PART(c,d))=0;
        end
        e=1;
        for d=1:sumn
            if temp(d)>0
                PARTCOMP(c,e)=temp(d);
                e=e+1;
            end
        end
    end
    if j==K
        PART=[PART PARTCOMP];
    else
        f=nchoosek(sumn-b,n(j));
        PART=[kron(PART,ones(f,1)) zeros(a*f,n(j)) ];
        for g=1:a
            PART((g-1)*f+1:g*f,b+1:b+n(j))=nchoosek(PARTCOMP(g,:),n(j));
        end
    end
end
[numpart,~]=size(PART);

% extracting indices for ambiguous and seeds

ambiguous=find(observe==-1);
maxm=max(m);
whereseeds=zeros(K,maxm);
for i=1:K
    temp=find(observe==i);
    whereseeds(i,1:m(i))=temp;
end

% computing logs

LG=log(Lam);
mLG=log( ones(K,K)-Lam );


% loop through all partitions

storelog= (-inf)*ones(sumn+summ,numpart);
for thispart=1:numpart
    
   % count edges between parts
    
   countA=zeros(K,K);
   countnotA=zeros(K,K);
   countS=zeros(K,K);
   countnotS=zeros(K,K);
   tempi=0;
   for i=1:K
       tempj=tempi;
       for j=i:K
           prtndi=ambiguous(  PART(thispart,tempi+1:tempi+n(i))  );
           prtndj=ambiguous(  PART(thispart,tempj+1:tempj+n(j))  );
           countA(i,j)=sum(sum(A(prtndi,prtndj)));
           countnotA(i,j)=n(i)*n(j)-countA(i,j);
           if i==j
              countA(i,j)=countA(i,j)/2;
              countnotA(i,j)=.5*n(i)*(n(i)-1) - countA(i,j);
           end
           tempj=tempj+n(j);
       end
       for h=1:K
           countS(i,h)=sum(sum(A(prtndi,whereseeds(h,1:m(h)))));
           countnotS(i,h)=n(i)*m(h)-countS(i,h);
       end
       tempi=tempi+n(i);
   end
   
   % get log prob for partition
   
   logsum=0;
   for i=1:K
       for j=i:K
           logsum=logsum+countA(i,j)*LG(i,j);
           logsum=logsum+countnotA(i,j)*mLG(i,j);
       end
       for h=1:K
           logsum=logsum+countS(i,h)*LG(i,h);
           logsum=logsum+countnotS(i,h)*mLG(i,h);
       end
   end
   prtnd1=ambiguous(  PART(thispart,1:n(1)  )  );
   storelog( prtnd1 ,thispart)=logsum;
end

% rescale and deliver

scalefac=max(max(storelog));
storelog=storelog-scalefac;
store=exp(storelog);
probs=sum(store,2);
probs=n(1)*probs/sum(probs);


X=[ -probs(ambiguous) rand(sumn,1) [1:sumn]' ];
Y=sortrows(X);

probs=probs(ambiguous(Y(:,3)));
reveal=      truth( ambiguous(Y(:,3)) )== 1;

vecprec=zeros(1,n(1));
for k=1:n(1)
    vecprec(k)=sum(reveal(1:k))/k;
end
avgprec=mean(vecprec);

end

