function [avgprec,reveal] = VNviaML(n,m,Lam,A,observe,truth, whichLAP)

%   [avgprec,reveal] = VNviaML(n,m,Lam,A,observe,truth)
%  n is vector of nonseed block sizes
%  m is vector of seed block sizes
%  Lam is communications matrix 
%  A is adjacency matrix
%  whichLAP is 1 or 2 according as slower/stable LAP or faster/less stable
%  
%  reveal is indicators of correctness along nomination list
%  pre-alpha version March 27, 2014 

K=length(n);
sumn=sum(n);
summ=sum(m);
sumnm=sumn+summ;
Lam=log(Lam./(1-Lam)); % Turn the communication probabilities to logs

% bookkeeping-- put all seeds first

loc=[];
for i=1:K
    findit=find(observe==i);
    loc=[loc; findit];
end
findit=find(observe==-1);
loc=[loc; findit];
A=A(loc,loc);
observe=observe(loc);
truth=truth(loc);

% make average graph

avloc=[];
for i=1:K
    avloc=[avloc; i*ones(m(i),1)];
end
for i=1:K
    avloc=[avloc; i*ones(n(i),1)];
end   

B=zeros(sumnm,sumnm);
for i=1:sumnm
    for j=1:sumnm
        B(i,j)=Lam(avloc(i),avloc(j));
    end
end
B=B-diag(diag(B));

% do graph match and nominate

corr=seedgraphmatchell2(A,B,summ,whichLAP);
susp= find ( (corr>summ)&(corr<=summ+n(1)) );
nonsusp= find(corr>summ+n(1));

CurB=B(corr,corr);

pdiffsusp=zeros(n(1),1);
pdiffnonsusp=zeros(sumn-n(1),1);

for zz=1:n(1)
    for yy=1:sumn-n(1)
        for qq=1:sumnm
            if ~( (qq== susp(zz) )|(qq==nonsusp(yy) ) )
                am=A(qq,susp(zz))*CurB(qq,susp(zz))+A(qq,nonsusp(yy))*CurB(qq,nonsusp(yy))-A(qq,susp(zz))*CurB(qq,nonsusp(yy))-A(qq,nonsusp(yy))*CurB(qq,susp(zz));
                pdiffsusp(zz)=pdiffsusp(zz)+am/(sumnm-n(1));
                pdiffnonsusp(yy)=pdiffnonsusp(yy)+am/(n(1));                
            end
        end        
    end
end


suspT=[ -pdiffsusp rand(n(1),1) susp'];
suspT=sortrows(suspT);
nonsuspT=[  pdiffnonsusp rand(sumn-n(1),1) nonsusp'];
nonsuspT=sortrows(nonsuspT);
nominate=[ suspT(:,3); nonsuspT(:,3) ];

% now check on our success

reveal=  truth(nominate)==1;
vecprec=zeros(1,n(1));
for k=1:n(1)
    vecprec(k)=sum(reveal(1:k))/k;
end
avgprec=mean(vecprec);

end

